@@ -59,7 +59,7 @@ static unsigned short normal_i2c_range[] = { SENSORS_I2C_END };
 static unsigned int normal_isa[] = { SENSORS_ISA_END };
 static unsigned int normal_isa_range[] = { SENSORS_ISA_END };
 
-/* default VRM to 9.0 instead of 8.2 */
+/* default VRM to 9.0 */
 #define ASB100_DEFAULT_VRM 90
 
 /* Insmod parameters */
@@ -266,7 +266,7 @@ static struct i2c_driver asb100_driver = {
 #define ASB100_SYSCTL_FAN2	1102
 #define ASB100_SYSCTL_FAN3	1103
 
-#define ASB100_SYSCTL_TEMP1	1200	/* Degrees Celcius * 10 */
+#define ASB100_SYSCTL_TEMP1	1200	/* Degrees Celsius * 10 */
 #define ASB100_SYSCTL_TEMP2	1201
 #define ASB100_SYSCTL_TEMP3	1202
 #define ASB100_SYSCTL_TEMP4	1203
@@ -1006,7 +1006,7 @@ static void __exit asb100_exit(void)
 
 MODULE_AUTHOR(	"Mark M. Hoffman <mhoffman@lightlink.com>, "
 		"Frodo Looijaard <frodol@dds.nl>, "
-		"Philip Edelbrock <phil@netroedge.com>, and"
+		"Philip Edelbrock <phil@netroedge.com>, and "
 		"Mark Studebaker <mdsxyz123@yahoo.com>");
 
 MODULE_DESCRIPTION("ASB100 'Bach' driver");
