@@ -575,6 +575,7 @@
 #define SENSORS_W83627HF_PREFIX "w83627hf"
 #define SENSORS_W83627THF_PREFIX "w83627thf"
 #define SENSORS_W83637HF_PREFIX "w83637hf"
+#define SENSORS_W83687THF_PREFIX "w83687thf"
 
 #define SENSORS_W83791D_PREFIX "w83791d"
 
@@ -716,6 +717,7 @@
 /*#define SENSORS_W83792D_VID 61 */   /* R */
 /*#define SENSORS_W83792D_VRM 62 */   /* RW */
 #define SENSORS_W83792D_CHASSIS 63    /* R */
+#define SENSORS_W83792D_ALARMS 64     /* R */
 
 #define SENSORS_W83792D_FAN1_DIV 71 /* RW */
 #define SENSORS_W83792D_FAN2_DIV 72 /* RW */
@@ -726,6 +728,29 @@
 #define SENSORS_W83792D_FAN7_DIV 77 /* RW */
 
 
+/* Winbond W83793R chip */
+#define SENSORS_W83793_PREFIX "w83793"
+
+#define SENSORS_W83793_IN(n)		(0 + (n))  /* n(0-9) R */
+#define SENSORS_W83793_IN_MIN(n)	(20 + (n)) /* n(0-9) RW */
+#define SENSORS_W83793_IN_MAX(n)	(40 + (n)) /* n(0-9) RW */
+#define SENSORS_W83793_IN_ALARM(n)	(60 + (n)) /* n(0-9) R */
+
+#define SENSORS_W83793_FAN(n)		(80 + (n))  /* n(1-12) R */
+#define SENSORS_W83793_FAN_MIN(n)	(100 + (n)) /* n(1-12) RW */
+#define SENSORS_W83793_FAN_ALARM(n)	(120 + (n)) /* n(1-12) R */
+
+
+#define SENSORS_W83793_TEMP(n)		(140 + (n)) /* n(1-6) R */
+#define SENSORS_W83793_TEMP_CRIT(n)	(160 + (n)) /* n(1-6) RW */
+#define SENSORS_W83793_TEMP_CRIT_HYST(n) (180 + (n)) /* n(1-6) RW */
+#define SENSORS_W83793_TEMP_ALARM(n)	(200 + (n)) /* n(1-6) R */
+
+#define SENSORS_W83793_VID0		221 /* R */
+#define SENSORS_W83793_VID1		222 /* R */
+#define SENSORS_W83793_VRM		230 /* RW */
+#define SENSORS_W83793_CHASSIS		240 /* RW */
+
 
 #define SENSORS_AS99127F_PREFIX "as99127f"
 
@@ -847,11 +872,56 @@
 
 #define SENSORS_W83627EHF_PREFIX	"w83627ehf"
 
+#define SENSORS_W83627EHF_IN0		1 /* R */
+#define SENSORS_W83627EHF_IN1		2 /* R */
+#define SENSORS_W83627EHF_IN2		3 /* R */
+#define SENSORS_W83627EHF_IN3		4 /* R */
+#define SENSORS_W83627EHF_IN4		5 /* R */
+#define SENSORS_W83627EHF_IN5		6 /* R */
+#define SENSORS_W83627EHF_IN6		7 /* R */
+#define SENSORS_W83627EHF_IN7		8 /* R */
+#define SENSORS_W83627EHF_IN8		9 /* R */
+#define SENSORS_W83627EHF_IN9 		10 /* R */
+#define SENSORS_W83627EHF_IN0_ALARM	111 /* R */
+#define SENSORS_W83627EHF_IN1_ALARM	112 /* R */
+#define SENSORS_W83627EHF_IN2_ALARM	113 /* R */
+#define SENSORS_W83627EHF_IN3_ALARM	114 /* R */
+#define SENSORS_W83627EHF_IN4_ALARM	115 /* R */
+#define SENSORS_W83627EHF_IN5_ALARM	116 /* R */
+#define SENSORS_W83627EHF_IN6_ALARM	117 /* R */
+#define SENSORS_W83627EHF_IN7_ALARM	118 /* R */
+#define SENSORS_W83627EHF_IN8_ALARM	119 /* R */
+#define SENSORS_W83627EHF_IN9_ALARM	120 /* R */
+#define SENSORS_W83627EHF_IN0_MIN	11 /* RW */
+#define SENSORS_W83627EHF_IN1_MIN	12 /* RW */
+#define SENSORS_W83627EHF_IN2_MIN	13 /* RW */
+#define SENSORS_W83627EHF_IN3_MIN	14 /* RW */
+#define SENSORS_W83627EHF_IN4_MIN	15 /* RW */
+#define SENSORS_W83627EHF_IN5_MIN	16 /* RW */
+#define SENSORS_W83627EHF_IN6_MIN	17 /* RW */
+#define SENSORS_W83627EHF_IN7_MIN	18 /* RW */
+#define SENSORS_W83627EHF_IN8_MIN	19 /* RW */
+#define SENSORS_W83627EHF_IN9_MIN	20 /* RW */
+#define SENSORS_W83627EHF_IN0_MAX	21 /* RW */
+#define SENSORS_W83627EHF_IN1_MAX	22 /* RW */
+#define SENSORS_W83627EHF_IN2_MAX	23 /* RW */
+#define SENSORS_W83627EHF_IN3_MAX	24 /* RW */
+#define SENSORS_W83627EHF_IN4_MAX	25 /* RW */
+#define SENSORS_W83627EHF_IN5_MAX	26 /* RW */
+#define SENSORS_W83627EHF_IN6_MAX	27 /* RW */
+#define SENSORS_W83627EHF_IN7_MAX	28 /* RW */
+#define SENSORS_W83627EHF_IN8_MAX	29 /* RW */
+#define SENSORS_W83627EHF_IN9_MAX	30 /* RW */
 #define SENSORS_W83627EHF_FAN1		31 /* R  */
 #define SENSORS_W83627EHF_FAN2		32 /* R  */
 #define SENSORS_W83627EHF_FAN3		33 /* R  */
 #define SENSORS_W83627EHF_FAN4		34 /* R  */
 #define SENSORS_W83627EHF_FAN5		35 /* R  */
+#define SENSORS_W83627EHF_FAN1_ALARM	131 /* R  */
+#define SENSORS_W83627EHF_FAN2_ALARM	132 /* R  */
+#define SENSORS_W83627EHF_FAN3_ALARM	133 /* R  */
+#define SENSORS_W83627EHF_FAN4_ALARM	134 /* R  */
+#define SENSORS_W83627EHF_FAN5_ALARM	135 /* R  */
 #define SENSORS_W83627EHF_FAN1_MIN	41 /* RW */
 #define SENSORS_W83627EHF_FAN2_MIN	42 /* RW */
 #define SENSORS_W83627EHF_FAN3_MIN	43 /* RW */
@@ -865,6 +935,9 @@
 #define SENSORS_W83627EHF_TEMP1		61 /* R  */
 #define SENSORS_W83627EHF_TEMP2		62 /* R  */
 #define SENSORS_W83627EHF_TEMP3		63 /* R  */
+#define SENSORS_W83627EHF_TEMP1_ALARM	161 /* R  */
+#define SENSORS_W83627EHF_TEMP2_ALARM	162 /* R  */
+#define SENSORS_W83627EHF_TEMP3_ALARM	163 /* R  */
 #define SENSORS_W83627EHF_TEMP1_OVER	71 /* RW */
 #define SENSORS_W83627EHF_TEMP2_OVER	72 /* RW */
 #define SENSORS_W83627EHF_TEMP3_OVER	73 /* RW */
@@ -876,9 +949,10 @@
 /* Analog Devices ADM9240 chips */
 
 #define SENSORS_ADM9240_PREFIX "adm9240"
-/* Cheat on LM81 for now - no separate #defines */
 #define SENSORS_LM81_PREFIX "lm81"
+#define SENSORS_DS1780_PREFIX "ds1780"
 
+/* All three chips have the same features */
 #define SENSORS_ADM9240_IN0 1 /* R */
 #define SENSORS_ADM9240_IN1 2 /* R */
 #define SENSORS_ADM9240_IN2 3 /* R */
@@ -910,40 +984,6 @@
 #define SENSORS_ADM9240_ALARMS 81 /* R */
 #define SENSORS_ADM9240_ANALOG_OUT 82 /* RW */
 
-/* Analog Devices ADM9240 chips */
-
-#define SENSORS_DS1780_PREFIX "ds1780"
-
-#define SENSORS_DS1780_IN0 1 /* R */
-#define SENSORS_DS1780_IN1 2 /* R */
-#define SENSORS_DS1780_IN2 3 /* R */
-#define SENSORS_DS1780_IN3 4 /* R */
-#define SENSORS_DS1780_IN4 5 /* R */
-#define SENSORS_DS1780_IN5 6 /* R */
-#define SENSORS_DS1780_IN0_MIN 11 /* RW */
-#define SENSORS_DS1780_IN1_MIN 12 /* RW */
-#define SENSORS_DS1780_IN2_MIN 13 /* RW */
-#define SENSORS_DS1780_IN3_MIN 14 /* RW */
-#define SENSORS_DS1780_IN4_MIN 15 /* RW */
-#define SENSORS_DS1780_IN5_MIN 16 /* RW */
-#define SENSORS_DS1780_IN0_MAX 21 /* RW */
-#define SENSORS_DS1780_IN1_MAX 22 /* RW */
-#define SENSORS_DS1780_IN2_MAX 23 /* RW */
-#define SENSORS_DS1780_IN3_MAX 24 /* RW */
-#define SENSORS_DS1780_IN4_MAX 25 /* RW */
-#define SENSORS_DS1780_IN5_MAX 26 /* RW */
-#define SENSORS_DS1780_FAN1 31 /* R */
-#define SENSORS_DS1780_FAN2 32 /* R */
-#define SENSORS_DS1780_FAN1_MIN 41 /* RW */
-#define SENSORS_DS1780_FAN2_MIN 42 /* RW */
-#define SENSORS_DS1780_TEMP 51 /* R */
-#define SENSORS_DS1780_TEMP_HYST 52 /* RW */
-#define SENSORS_DS1780_TEMP_OVER 53 /* RW */
-#define SENSORS_DS1780_VID 61 /* R */
-#define SENSORS_DS1780_FAN1_DIV 71 /* RW */
-#define SENSORS_DS1780_FAN2_DIV 72 /* RW */
-#define SENSORS_DS1780_ALARMS 81 /* R */
-#define SENSORS_DS1780_ANALOG_OUT 82 /* RW */
 
 /* SiS southbridge with integrated lm78 */
 
@@ -1524,6 +1564,8 @@
 
 #define SENSORS_IT87_PREFIX "it87"
 #define SENSORS_IT8712_PREFIX "it8712"
+#define SENSORS_IT8716_PREFIX "it8716"
+#define SENSORS_IT8718_PREFIX "it8718"
 
 #define SENSORS_IT87_IN0 1 /* R */
 #define SENSORS_IT87_IN1 2 /* R */
@@ -1721,28 +1763,25 @@
 #define SENSORS_VT1211_IN3 4 /* R */
 #define SENSORS_VT1211_IN4 5 /* R */
 #define SENSORS_VT1211_IN5 6 /* R */
-#define SENSORS_VT1211_IN6 7 /* R */
 #define SENSORS_VT1211_IN0_MIN 11 /* RW */
 #define SENSORS_VT1211_IN1_MIN 12 /* RW */
 #define SENSORS_VT1211_IN2_MIN 13 /* RW */
 #define SENSORS_VT1211_IN3_MIN 14 /* RW */
 #define SENSORS_VT1211_IN4_MIN 15 /* RW */
 #define SENSORS_VT1211_IN5_MIN 16 /* RW */
-#define SENSORS_VT1211_IN6_MIN 17 /* RW */
 #define SENSORS_VT1211_IN0_MAX 21 /* RW */
 #define SENSORS_VT1211_IN1_MAX 22 /* RW */
 #define SENSORS_VT1211_IN2_MAX 23 /* RW */
 #define SENSORS_VT1211_IN3_MAX 24 /* RW */
 #define SENSORS_VT1211_IN4_MAX 25 /* RW */
 #define SENSORS_VT1211_IN5_MAX 26 /* RW */
-#define SENSORS_VT1211_IN6_MAX 27 /* RW */
 #define SENSORS_VT1211_FAN1 31 /* R */
 #define SENSORS_VT1211_FAN2 32 /* R */
 #define SENSORS_VT1211_FAN1_MIN 41 /* RW */
 #define SENSORS_VT1211_FAN2_MIN 42 /* RW */
-#define SENSORS_VT1211_TEMP 51 /* R */
-#define SENSORS_VT1211_TEMP_HYST 52 /* RW */
-#define SENSORS_VT1211_TEMP_OVER 53 /* RW */
+#define SENSORS_VT1211_TEMP1 51 /* R */
+#define SENSORS_VT1211_TEMP1_HYST 52 /* RW */
+#define SENSORS_VT1211_TEMP1_OVER 53 /* RW */
 #define SENSORS_VT1211_TEMP2 54 /* R */
 #define SENSORS_VT1211_TEMP2_HYST 55 /* RW */
 #define SENSORS_VT1211_TEMP2_OVER 56 /* RW */
@@ -1778,6 +1817,21 @@
 #define SENSORS_SMSC47M1_FAN2_DIV 76 /* RW */
 #define SENSORS_SMSC47M1_ALARMS 81 /* R */
 
+#define SENSORS_SMSC47M192_PREFIX "smsc47m192"
+
+#define SENSORS_SMSC47M192_IN(n)		(1 + (n))	/* R */
+#define SENSORS_SMSC47M192_IN_MIN(n)		(21 + (n))	/* RW */
+#define SENSORS_SMSC47M192_IN_MAX(n)		(41 + (n))	/* RW */
+#define SENSORS_SMSC47M192_IN_ALARM(n)		(61 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP(n)		(100 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP_MAX(n)		(120 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_MIN(n)		(140 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_OFFSET(n)	(160 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_ALARM(n)	(180 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP_FAULT(n)	(200 + (n))	/* R */
+#define SENSORS_SMSC47M192_VID			301		/* R */
+#define SENSORS_SMSC47M192_VRM			302		/* RW */
+
 #define SENSORS_PC87360_PREFIX "pc87360"
 #define SENSORS_PC87363_PREFIX "pc87363"
 #define SENSORS_PC87364_PREFIX "pc87364"
@@ -1896,21 +1950,18 @@
 #define SENSORS_VT8231_IN3 4 /* R */
 #define SENSORS_VT8231_IN4 5 /* R */
 #define SENSORS_VT8231_IN5 6 /* R */
-#define SENSORS_VT8231_IN6 7 /* R */
 #define SENSORS_VT8231_IN0_MIN 11 /* RW */
 #define SENSORS_VT8231_IN1_MIN 12 /* RW */
 #define SENSORS_VT8231_IN2_MIN 13 /* RW */
 #define SENSORS_VT8231_IN3_MIN 14 /* RW */
 #define SENSORS_VT8231_IN4_MIN 15 /* RW */
 #define SENSORS_VT8231_IN5_MIN 16 /* RW */
-#define SENSORS_VT8231_IN6_MIN 17 /* RW */
 #define SENSORS_VT8231_IN0_MAX 21 /* RW */
 #define SENSORS_VT8231_IN1_MAX 22 /* RW */
 #define SENSORS_VT8231_IN2_MAX 23 /* RW */
 #define SENSORS_VT8231_IN3_MAX 24 /* RW */
 #define SENSORS_VT8231_IN4_MAX 25 /* RW */
 #define SENSORS_VT8231_IN5_MAX 26 /* RW */
-#define SENSORS_VT8231_IN6_MAX 27 /* RW */
 #define SENSORS_VT8231_FAN1 31 /* R */
 #define SENSORS_VT8231_FAN2 32 /* R */
 #define SENSORS_VT8231_FAN1_MIN 41 /* RW */
@@ -1933,9 +1984,6 @@
 #define SENSORS_VT8231_TEMP6 66 /* R */
 #define SENSORS_VT8231_TEMP6_HYST 67 /* RW */
 #define SENSORS_VT8231_TEMP6_OVER 68 /* RW */
-#define SENSORS_VT8231_TEMP7 69 /* R */
-#define SENSORS_VT8231_TEMP7_HYST 70 /* RW */
-#define SENSORS_VT8231_TEMP7_OVER 71 /* RW */
 #define SENSORS_VT8231_FAN1_DIV 75 /* RW */
 #define SENSORS_VT8231_FAN2_DIV 76 /* RW */
 #define SENSORS_VT8231_ALARMS 81 /* R */
@@ -2122,4 +2170,50 @@
 #define SENSORS_SMSC47B397_FAN3		0x13 /* R */
 #define SENSORS_SMSC47B397_FAN4		0x14 /* R */
 
+/* Fintek F71805F chip */
+#define SENSORS_F71805F_PREFIX		"f71805f"
+
+/* in n from 0 to 8 */
+#define SENSORS_F71805F_IN(n)		(1 + (n))
+#define SENSORS_F71805F_IN_MIN(n)	(16 + (n))
+#define SENSORS_F71805F_IN_MAX(n)	(31 + (n))
+/* fan n from 1 to 3 */
+#define SENSORS_F71805F_FAN(n)		(50 + (n))
+#define SENSORS_F71805F_FAN_MIN(n)	(60 + (n))
+/* temp n from 1 to 3 */
+#define SENSORS_F71805F_TEMP(n)		(80 + (n))
+#define SENSORS_F71805F_TEMP_MAX(n)	(90 + (n))
+#define SENSORS_F71805F_TEMP_HYST(n)	(100 + (n))
+#define SENSORS_F71805F_TEMP_TYPE(n)	(110 + (n))
+/* alarms */
+#define SENSORS_F71805F_ALARMS_IN	200
+#define SENSORS_F71805F_ALARMS_FAN	201
+#define SENSORS_F71805F_ALARMS_TEMP	202
+
+/* Abit uGuru chip */
+#define SENSORS_ABITUGURU_PREFIX "abituguru"
+
+/* in n from 0 to 10 */
+#define SENSORS_ABITUGURU_IN(n)			(0x01 + (n)) /* R */
+#define SENSORS_ABITUGURU_IN_MIN(n)		(0x11 + (n)) /* RW */
+#define SENSORS_ABITUGURU_IN_MIN_ALARM(n)	(0x21 + (n)) /* R */
+#define SENSORS_ABITUGURU_IN_MAX(n)		(0x31 + (n)) /* RW */
+#define SENSORS_ABITUGURU_IN_MAX_ALARM(n)	(0x41 + (n)) /* R */
+/* temp n from 1 to 7 */
+#define SENSORS_ABITUGURU_TEMP(n)		(0x50 + (n)) /* R */
+#define SENSORS_ABITUGURU_TEMP_ALARM(n)		(0x60 + (n)) /* R */
+#define SENSORS_ABITUGURU_TEMP_MAX(n)		(0x70 + (n)) /* RW */
+#define SENSORS_ABITUGURU_TEMP_CRIT(n)		(0x80 + (n)) /* RW */
+/* fan n from 1 to 6 */
+#define SENSORS_ABITUGURU_FAN(n)		(0x90 + (n)) /* R */
+#define SENSORS_ABITUGURU_FAN_ALARM(n)		(0xA0 + (n)) /* R */
+#define SENSORS_ABITUGURU_FAN_MIN(n)		(0xB0 + (n)) /* RW */
+
+/* K8TEMP */
+#define SENSORS_K8TEMP_PREFIX "k8temp"
+#define SENSORS_K8TEMP_TEMP1	0x01 /* R */
+#define SENSORS_K8TEMP_TEMP2	0x02 /* R */
+#define SENSORS_K8TEMP_TEMP3	0x03 /* R */
+#define SENSORS_K8TEMP_TEMP4	0x04 /* R */
+
 #endif /* def LIB_SENSORS_CHIPS_H */
